.. _exceptions:

.. module:: akismet
  :noindex:


Exception classes
=================

The following Akismet-specific exception classes may be raised while using the
Akismet API clients:

.. autoexception:: AkismetError
.. autoexception:: APIKeyError
.. autoexception:: ConfigurationError
.. autoexception:: RequestError
.. autoexception:: ProtocolError
.. autoexception:: UnknownArgumentError
